<template>
	<view class="uni-page-modal-form">
		<view class="view-content">
			<!-- 表头样式 -->
			<OIForm ref="refBaseForm" class="v-head-style" :form="head_styledef.form" :focusId="focusFieldId"
				@on-click="onClick" @on-focus="ontap" @on-change="onEnterChange" @on-click-prefix="classAttr_extButton"
				@on-click-suffix="classAttr_extButton"></OIForm>
		</view>
		<view class="view-bottom">
			<button type="primary" @tap="ok" class="btn_add" :class="okLoading?'btn_disabled':''"
				:disabled="okLoading">{{translateSys('ok')}}</button>
			<button type="default" @tap="cancel" class="btn_cancel">{{translateSys('cancel')}}</button>

		</view>
		<view>
			<uni-popup class="view-popup" ref="popup" background-color="#fff" @change="popupChange">
				<view class="popup-header">{{check_list.title}}</view>
				<view class="popup-content" :class="{ 'popup-height': popupType === 'left' || popupType === 'right' }"
					:style="{'width':check_list.width?check_list.width+'px':'375rpx','height':check_list.height?check_list.height+'px':popupType =='center'?'60vh':'88vh'}">
					<view class="popup-cont"
						:style="{'height':check_list.height?check_list.height-45+'px':popupType =='center'?'50vh':'80vh'}">
						<view class="view_popup_CheckList" v-for="(item,index) in check_list.items">
							<checkbox-group class="check_list" @change="checkChange" :data-ischeck="item.check"
								:data-index="index" :style="{'margin-left': '10rpx'}">
								<label>
									<checkbox :value="item.check" :checked="item.check" />
									<text>{{item.name}}</text>
								</label>
							</checkbox-group>
						</view>
					</view>
					<view class="popup-footer">
						<button type="primary" @tap="popup_sava" class="btn_popup_add">{{translateSys('ok')}}</button>
						<button type="default" @tap="popup_cancel"
							class="btn_popup_cancel">{{translateSys('cancel')}}</button>
					</view>
				</view>
			</uni-popup>
		</view>
	</view>
</template>

<script>
	import {
		Base64
	} from  '@/js/Base64.js';
	import {
		dictGetInfo
	} from "@/api/mobox.js"
	import {
		getUIStyleInfo,
		runCustomEvent,
		dataObjCreate,
		updateDataObj,
		dataObjInfo
	} from "@/api/data.js"
	import dayjs from "dayjs";
	import OIForm from '@/components/oi-form/index.vue'

	export default {
		name: "PageModalForm",
		components: {
			OIForm
		},
		data() {
			return {
				okLoading: false,
				title: this.translateSys('add2'),
				type: '',
				editMode: false,
				clsId: '',
				objId: "",
				param: {},
				focusFieldId: "",
				focusOldFieldId: "",
				head_styledef: {
					form: {
						items: [],
						model: {}
					}
				},
				global_attr: [],
				ext_info: {},
				data_json: [],
				popupType: "center",
				check_list: {},
				popupParam: {},
			};
		},
		computed: {
			initialEvent() {
				let event = this.head_styledef.event?.find((e) => e.event_id == "initial");
				return {
					id: event?.scrip_id,
					name: event?.scrip_name,
				};
			},
			beforeOKEvent() {
				let event = this.head_styledef.event?.find((e) => e.event_id == "before_ok");
				return {
					id: event?.scrip_id,
					name: event?.scrip_name,
				};
			},
			afterOKEvent() {
				let event = this.head_styledef.event?.find((e) => e.event_id == "after_ok");
				return {
					id: event?.scrip_id,
					name: event?.scrip_name,
				};
			},
			beforeCancelEvent() {
				let event = this.head_styledef.event?.find(
					(e) => e.event_id == "before_cancel"
				);
				return {
					id: event?.scrip_id,
					name: event?.scrip_name,
				};
			},
			afterCancelEvent() {
				let event = this.head_styledef.event?.find(
					(e) => e.event_id == "after_cancel"
				);
				return {
					id: event?.scrip_id,
					name: event?.scrip_name,
				};
			},
		},
		onLoad(options) {

			this.param = JSON.parse(options.param);
			let objAttr
			if (options.type) {
				this.type = options.type;
			}
			//获取主数据类ID
			this.clsId = this.param.Cls_ID;
			this.objId = options.objId || "";
			this.editMode = options.editMode ? true : false;
			if (options.objAttr)
				objAttr = JSON.parse(options.objAttr);
			if (options.globalAttrs)
				this.global_attr = JSON.parse(options.globalAttrs);
			if (options.extInfo)
				this.ext_info = JSON.parse(options.extInfo);
			if (options.dataJson)
				this.data_json = JSON.parse(options.dataJson);
			this.title = options.titlename ? options.titlename : this.param.ShowName; //设置按钮文字
			// console.log(options)
			uni.setNavigationBarTitle({
				title: this.title
			}); //设置顶部标题 

			if (this.clsId) {
				this.loadData(objAttr)
			} else {
				uni.showModal({
					title: this.translateSys("error"),
					content: this.translate("tip_no_master_class"),
					showCancel: false,
					confirmText: this.translateSys('close')
				});
			}
		},
		//页面初始化获取焦点
		methods: {
			setData(obj) {
				let that = this;
				let keys = [];
				let val, data;

				Object.keys(obj).forEach(function(key) {
					keys = key.split(".");
					val = obj[key];
					data = that.$data;
					keys.forEach(function(key2, index) {
						if (index + 1 == keys.length) {
							that.$set(data, key2, val);
							console.log("$set", key2, val)
						} else {
							if (!data[key2]) {
								that.$set(data, key2, {});
								console.log("$set", key2, {})
							}
						}
						data = data[key2];
					});
				});
			},
			async loadData(objAttr) {

				//获取数据类的自定义表单参数
				await this.Head_UIStyleGetInfo(this.clsId, this.param.Edit_dlg.ID);
				// form data
				await this.loadFormData(objAttr);
				// init event
				await this.loadInitialEvent();
			},

			async Head_UIStyleGetInfo(class_id, style_id) { //获取自定义表单样式
				try {
					var $this = this;
					var dataInfo = {
						class_id: class_id,
						ui_style_id: style_id,
					};
					const result = await getUIStyleInfo(dataInfo)
					var styledef = "";
					if (result.style_def) {
						//mobox2的style_def是json字符串
						styledef = result.style_def.replace(/\\/g, "");
						//mobox3的style_def是base64字符串
						if (!result.style_def.includes('"')) styledef = Base64.decode(
							result
							.style_def);
					}
					const styledefHead = styledef ? JSON.parse(styledef) : {};
					if (styledefHead?.form?.items) {
						for (let i in styledefHead.form.items) {
							const ele = styledefHead.form.items[i]
							if (ele.name != "Layout") {
								if (ele?.useDict) {
									//判断useDict是否使用字典
									await this.DictGetInfo(ele.bind.dict,
										styledefHead.form.model,
										ele);
								} else {
									if (ele?.name === "Select") {
										const selections = ele?.selections || []
										//有默认值，显示默认值
										let itemName = ele.value || "";
										if (itemName) {
											styledefHead.form
												.model[ele.fieldId] = itemName;
										}
										ele.selections = selections.map((a) => {
											return {
												value: a.value,
												text: a.label
											}
										})

									}

								}

								if ($this.focusFieldId == "") {
									if (ele.name == 'Input' || ele.name ==
										'InputNumber') {
										$this.setData({
											focusFieldId: ele.fieldId
										})
									}
								}
							} else {
								for (let j in ele.setting.colList) {
									const col = ele.setting.colList[j]
									if (col?.useDict) {
										//判断useDict是否使用字典
										await this.DictGetInfo(col.bind
											.dict,
											styledefHead.form
											.model, col);
									} else {
										if (col?.name === "Select") {
											const selections = col?.selections || []
											//有默认值，显示默认值
											let itemName = col.value || "";
											if (itemName) {
												styledefHead.form
													.model[col.fieldId] = itemName;
											}
											col.selections = selections.map((a) => {
												return {
													value: a.value,
													text: a.label
												}
											})
										}
									}
									if ($this.focusFieldId == "") {
										if (col.name == 'Input' || col
											.name ==
											'InputNumber') {
											$this.setData({
												focusFieldId: col
													.fieldId
											})
										}
									}
								}
							}
						}

					}
					this.setData({
						head_styledef: styledefHead
					})
					console.log("Head_UIStyleGetInfo", this.head_styledef)

				} catch (ex) {
					// console.log(ex);
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: $this.translateSys('tip') + "1",
						content: exStr,
						showCancel: false,
						confirmText: $this.translateSys('close')
					});

				}


			},
			async DictGetInfo(dict, formModel, formItem) { //Mobox3得到得到字典信息字典项列表
				this.data = [];
				var $this = this;
				var dataInfo = {
					dict_id: dict.id,
					dict_name: dict.name
				};
				try {
					const result = await dictGetInfo(dataInfo)
					var list = [];
					var itemName = '';
					(result.dict_item_list || []).forEach((item) => {
						if (item.is_default == '1')
							itemName = item.name
						list.push({
							text: item.value ? item.value : item.name,
							value: item.name,
						});
					});
					//有默认值，显示默认值
					if (itemName) {
						formItem.value = itemName;
						formModel[formItem.fieldId] = itemName;
					}
					formItem.dict = list;
				} catch (ex) {
					// console.log(ex);
					uni.showModal({
						title: this.translateSys("error") + "3",
						content: ex.errMsg,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				}

			},
			async loadFormData(objAttr) {
				let attrs = []

				if (this.objId) {
					let info = await dataObjInfo({
						class_id: this.clsId,
						obj_id: this.objId,
					});

					attrs = [{
						attr: "id",
						value: info.id
					}, {
						attr: "state",
						value: info.state
					}]
					info.attr_list.forEach(({
						name,
						value
					}) => {
						attrs.push({
							attr: name,
							value: value
						})
					});
					this.setFormValues(attrs)
				} else if (objAttr) {
					Object.keys(objAttr).forEach((attr) => {
						attrs.push({
							attr: attr,
							value: objAttr[attr]
						})
					});
					this.setFormValues(attrs)
				}


			},
			async loadInitialEvent() {
				try {
					if (this.initialEvent.id) {
						let obj_attr = this.head_styledef.form.model;
						let inputParam = {
							id: "",
							attrs: Object.keys(obj_attr).map((a) => ({
								attr: a,
								value: obj_attr[a],
							})),
						};
						let input_param = Base64.encode(JSON.stringify(inputParam));
						let global_attr = Base64.encode(JSON.stringify(this.global_attr)); //将字符串转换为base64编码
						let data_json = Base64.encode(JSON.stringify(this.data_json)); //将字符串转换为base64编码
						let ext_info = Base64.encode(JSON.stringify(this.ext_info)); //将字符串转换为base64编码
						const result = await runCustomEvent({
							ed_type: 0,
							class_id: this.clsId,
							event_id: this.initialEvent.id,
							data_obj_id: this.objId,
							obj_attr,
							input_param,
							global_attr,
							data_json,
							ext_info
						})
						if (result.ret != 0) {
							var tip = result.err_info ? typeof result
								.err_info == 'string' ? result
								.err_info : result.err_info.join('<br/>') :
								'';
							if (result.ret == 801) {
								if (this.param.Only_Script_Error) {
									let pos = tip.indexOf("：");
									if (pos > -1) tip = tip.substring(pos +
										1);
								}
								uni.showModal({
									title: this.translateSys(
										"tip"),
									content: tip,
									showCancel: false,
									confirmText: this.translateSys(
										'close')
								});
							} else uni.showModal({
								title: this.translateSys('tip'),
								content: tip + ',' + this
									.translateSys('tip') + ':' +
									result
									.ret,
								showCancel: false,
								confirmText: this.translateSys(
									'close')
							});
							return false;
						} else {
							var tip = result.info ? typeof result.info ==
								'string' ? result.info :
								result.info.join('<br/>') : '';
							if (tip) uni.showModal({
								title: this.translateSys('tip'),
								content: tip,
								showCancel: false,
								confirmText: this.translateSys(
									'close')
							});

							if (result.result_type == 0 && result.action) {
								result.action.forEach(item => {

									if (item.action_type ==
										"set_dlg_current_edit_attr"
									) {

										if ($this
											.focusOldFieldId ==
											item.value) {
											$this.setData({
												focusFieldId: ""
											})
										} else {
											$this.setData({
												focusFieldId: $this
													.focusOldFieldId
											})
										}
										$this.$nextTick(() => {
											$this.setData({
												focusFieldId: item
													.value
											})
										});
									} else if (item.action_type ==
										"set_dlg_attr") {
										// value = {"attr":"xxx", "value":"xxx"}
										var data = item.value;
										$this.setFormValues(data)
									}
								});
							} else {

								if (result.info) {
									uni.showModal({
										title: this.translateSys(
											"error") + "4.3",
										content: result.info,
										showCancel: false,
										confirmText: this
											.translateSys('close')
									});
								}
							}

						}

					}
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: $this.translateSys('tip') + "2",
						content: exStr,
						showCancel: false,
						confirmText: $this.translateSys('close')
					});
				}
			},
			onClick(item) {
				this.focusFieldId = item.fieldId
			},
			ontap(item) { //扫码功能
				// var $ele = e;
				//console.log(e.target)
				this.focusOldFieldId = item.fieldId
				getApp().onScan((result) => {
					console.log(result.decodedata);
					item.value = result.decodedata;
					var $this = this;
					let newVal = item.value.trim()
					if (newVal) {
						item.oldvalue = newVal;
						var attr = item.fieldId;
						this.head_styledef.form.model[attr] = newVal;
						var onChangeEvent = item.bind.onChangeEvent; //内容变化后事件
						var onSuffixClickCallbackEvent = item.bind
							.onSuffixClickCallbackEvent; //后图标点击事件
						var onSuffixClickEvent = item.bind
							.onSuffixClickEvent; //后图标点击回调
						var isflag = false;

						if (onChangeEvent?.id) { //内容变化后事件
							$this.onChange(onChangeEvent);
						}
						//初始化，下个输入框focus属性
						var findd = false
						for (let i in $this.head_styledef.form.items) {
							const ele = $this.head_styledef.form.items[i]

							if (ele.name != "Layout") {
								if (ele.name == 'Input' || ele.name ==
									'InputNumber') {
									if (attr == ele.fieldId) {
										findd = true
									} else {
										if (findd) {
											$this.setData({
												focusFieldId: ele.fieldId
											})
											break
										}

									}

								}
							} else {
								if (findd) {
									let curIndex = ele.setting.colList.findIndex((
										col, index2, arr) => {
										return (col.name == 'Input' || col
											.name == 'InputNumber');
									})
									if (curIndex > -1) {
										$this.setData({
											focusFieldId: ele.setting
												.colList[curIndex]
												.fieldId
										})
										break
									}

								} else {
									let curIndex = ele.setting.colList.findIndex((
										col, index2, arr) => {
										return attr == col.fieldId;
									})
									if (curIndex > -1) {
										findd = true
										let curIndex2 = ele.setting.colList
											.findIndex((col, index2, arr) => {
												return (col.name == 'Input' ||
														col.name ==
														'InputNumber') &&
													index2 >
													curIndex;
											})
										if (curIndex2 > -1) {
											$this.setData({
												focusFieldId: ele.setting
													.colList[curIndex]
													.fieldId
											})
											break
										}
									}
								}

							}
						}

					}
				})
			},

			onEnterChange(item) { //回车，点击按钮，取消节点事件
				console.log(item);
				let newVal = item.value
				if (typeof item.value == "string") {
					newVal = item.value.trim()
					if (!newVal) {
						item.oldvalue = newVal;
						var attr = item.fieldId;
						this.head_styledef.form.model[attr] = newVal;
						return
					}
				}
				if (item.oldvalue != newVal) {
					item.oldvalue = newVal;
					var attr = item.fieldId;
					this.head_styledef.form.model[attr] = newVal;
					var onChangeEvent = item.bind.onChangeEvent; //内容变化后事件
					if (onChangeEvent?.id) { //内容变化后事件
						this.onChange(onChangeEvent);
					}

				}
			},
			classAttr_extButton(item) {
				var onSuffixClickCallbackEvent = item.bind.onSuffixClickCallbackEvent; //后图标点击事件
				var onSuffixClickEvent = item.bind.onSuffixClickEvent; //后图标点击回调

				if (!onSuffixClickCallbackEvent.id) {
					uni.showModal({
						title: this.translateSys("tip"),
						content: this.translate('icon_click_callback_empty'),
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return;
				}
				if (!onSuffixClickEvent.id) {
					uni.showModal({
						title: this.translateSys("tip"),
						content: this.translate('icon_click_event_empty'),
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return;
				}
				this.popupType = 'right'
				// open 方法传入参数 等同在 uni-popup 组件上绑定 type属性
				this.$refs.popup.open(this.popupType);

				this.dataObjRunCustomEvent_Return(onSuffixClickEvent.id, '', onSuffixClickCallbackEvent.id,
					item);
			},

			// 内容变化后事件
			async onChange(event) {
				try {
					if (event.id) {
						//获取表头属性
						var head_attr = {};
						this.head_styledef.form.items.forEach(item => {
							if (item.name == "Layout") { //判断是否是栅栏格式
								item.setting.colList.forEach(cols => {
									if (cols != null) head_attr[cols
										.fieldId] = cols.value;
								});
							} else
								head_attr[item.fieldId] = item.value;
						});
						var obj_attr = this.head_styledef.form.model;
						// console.log(obj_attr);
						var input_param = Base64.encode(
							JSON.stringify(
								Object.keys(head_attr).map((a) => ({
									attr: a,
									value: head_attr[a] || "",
								}))
							)
						);
						var $this = this;

						let global_attr = Base64.encode(JSON.stringify(this.global_attr))
						let data_json = Base64.encode(JSON.stringify(this.data_json))
						let ext_info = Base64.encode(JSON.stringify(this.ext_info))
						var dataInfo = {
							ed_type: 0,
							start_transaction: true,
							class_id: this.clsId,
							class_name: '',
							event_id: event.id,
							event_name: '',
							data_obj_id: '',
							obj_attr: obj_attr,
							prj_id: '',
							ref_cls_id: '',
							rel_obj_id: '',
							user_login: '',
							data_json,
							compose_info: '',
							ext_info,
							global_attr,
							input_param: input_param,
						};
						runCustomEvent(dataInfo).then(result => {
							console.log(result);

							if (result.ret != 0) {
								var tip = result.err_info ? typeof result
									.err_info == 'string' ? result
									.err_info : result.err_info.join('<br/>') :
									'';
								if (result.ret == 801) {
									if (this.param.Only_Script_Error) {
										let pos = tip.indexOf("：");
										if (pos > -1) tip = tip.substring(pos +
											1);
									}
									uni.showModal({
										title: this.translateSys(
											"tip"),
										content: tip,
										showCancel: false,
										confirmText: this.translateSys(
											'close')
									});
								} else uni.showModal({
									title: this.translateSys('tip'),
									content: tip + ',' + this
										.translateSys('tip') + ':' +
										result
										.ret,
									showCancel: false,
									confirmText: this.translateSys(
										'close')
								});
								return false;
							} else {
								var tip = result.info ? typeof result.info ==
									'string' ? result.info :
									result.info.join('<br/>') : '';
								if (tip) uni.showModal({
									title: this.translateSys('tip'),
									content: tip,
									showCancel: false,
									confirmText: this.translateSys(
										'close')
								});

								if (result.result_type == 0 && result.action) {
									result.action.forEach(item => {

										if (item.action_type ==
											"set_dlg_current_edit_attr"
										) {

											if ($this
												.focusOldFieldId ==
												item.value) {
												$this.setData({
													focusFieldId: ""
												})
											} else {
												$this.setData({
													focusFieldId: $this
														.focusOldFieldId
												})
											}
											$this.$nextTick(() => {
												$this.setData({
													focusFieldId: item
														.value
												})
											});
										} else if (item.action_type ==
											"set_dlg_attr") {
											// value = {"attr":"xxx", "value":"xxx"}
											var data = item.value;
											$this.setFormValues(data)
										}
									});
								} else {

									if (result.info) {
										uni.showModal({
											title: this.translateSys(
												"error") + "4.3",
											content: result.info,
											showCancel: false,
											confirmText: this
												.translateSys('close')
										});
									}
								}

							}

						}).catch(ex => {
							// console.log(ex);
							let tip = typeof ex.errMsg == "string" ? ex.errMsg : ex
							uni.showModal({
								title: this.translateSys("error") + "4.1",
								content: tip,
								showCancel: false,
								confirmText: this.translateSys('close')
							});
						});
					}
				} catch (ex) {
					var tip = typeof ex == "string" ? ex : ex.message;
					uni.showModal({
						title: this.translateSys("error") + "4.2",
						content: this.translate(
								'execute_after_change_event_failed') + this
							.translateSys(
								"comma") +
							this.translate('reason') + this.translateSys("colon") +
							tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				}
			},

			setFormValues(attrs) {
				console.log(attrs)
				const head_styledef = this.head_styledef
				if (JSON.stringify(attrs) == '{}') {
					return;
				}
				attrs.forEach(async (attr, key) => {
					if (attr.choice_list) {
						var dictItemList = [];
						attr.choice_list.forEach(async (val, index) => {
							dictItemList.push({
								text: val,
								value: val
							});
						});
						head_styledef.form.items.forEach(async (attr_item, index) => {
							if (attr_item.name != "Layout") {
								if (attr_item.fieldId == attr.attr) {
									if (attr_item.useDict) {
										attr_item.dict = dictItemList;
									} else {
										attr_item.selections = dictItemList;
									}
								}
							} else if (attr_item.name == "Layout") {
								attr_item.setting.colList.forEach((col) => {
									if (col) {
										if (col.fieldId == attr.attr) {
											if (col.useDict) {
												col.dict = dictItemList;
											} else {
												col.selections = dictItemList;
											}
										}
									}
								});
							}
						});
					}
					head_styledef.form.model[attr.attr] = attr.value;
					head_styledef.form.items.forEach(async (ele, index) => {
						if (ele.name != "Layout") {
							if (ele.fieldId == attr.attr) {
								ele.value = attr.value;
								ele.oldvalue = attr.value;
							}
						} else if (ele.name == "Layout") {
							ele.setting.colList.forEach((col) => {
								if (col) {
									if (col.fieldId == attr.attr) {
										col.value = attr.value;
										col.oldvalue = attr.value;
									}
								}
							});
						}

					})

					//判断表单里是否有返回字段，没有就装载到model里，点击确定提交的时候带上这些数据
				})
				console.log(head_styledef)
				this.setData({
					head_styledef: head_styledef
				})
			},
			popupChange(e) {
				console.log('当前模式：' + e.type + ',状态：' + e.show);
			},
			checkChange(e) { //弹框check选择
				// console.log(e.target.dataset);
				var index = e.target.dataset.index;
				var ischeck = e.target.dataset.ischeck;
				var data = this.check_list.items;
				// this.check_list.items=[];
				if (this.check_list.multiple_choice == "0") { //判断时单选还是多选
					for (var i in data) {
						data[i].check = false;
					}
				}
				data[index].check = ischeck ? false : true;
				this.check_list.items = data;

			},
			popup_cancel(e) { //弹框取消
				this.$refs.popup.close();
			},
			popup_sava(e) { //弹框确定
				var $this = this;
				var items = $this.check_list.items;
				var data = [];
				var name = "";
				for (var i = 0; i < items.length; i++) {
					if (items[i].check == true) {
						if (name)
							name += ';';
						name += items[i].name;
						data.push({
							id: items[i].id,
							name: items[i].name
						});
					}
				}
				if (!$this.popupParam) {
					uni.showModal({
						title: this.translateSys("tip"),
						content: "popupParam为空！",
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return;
				}
				if (data.length == 0) {
					uni.showModal({
						title: this.translateSys("tip"),
						content: this.translate("tip_no_select_data"),
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return;
				}
				let global_attr = Base64.encode(JSON.stringify(this.global_attr))
				let data_json = Base64.encode(JSON.stringify(this.data_json))
				let ext_info = Base64.encode(JSON.stringify(this.ext_info))
				var callback_eventid = $this.popupParam.button_callback.trim();
				var info = {
					eventid: callback_eventid,
					edtype: "0",
					projectid: '',
					rclsid: '',
					robjid: '',
					userlogin: '',
					clsid: $this.clsId,
					objid: "",
					attr: $this.popupParam.req,
					dataJson: data
				}
				$this.DataObjRunCustomEvent(info, $this.popupParam.data_attr);
				this.$refs.popup.close();
			},

			async DataObjRunCustomEvent(info, data_attr) {
				var $this = this;
				var enviroment = {
					'function': '3000', // 功能点编号
					cls_id: this.clsId, // 功能点主数据类标识
					'button': 'top', // top/bottom
					button_name: this.translateSys('add2'),
					master: {
						cls_id: this.clsId, // button=bottom时 master的cls_id
						//obj_id: ''  // button=bottom时 master的obj_id
					}
				};
				if (data_attr) {
					enviroment.edit_dlg = {
						type: 'small', //小窗口
						class_id: this.clsId, //当前数据类id
					}
					if (data_attr) {
						enviroment.edit_dlg.form_control = { //所属的表单控件
							name: data_attr.Name, //字段属性
							text: data_attr.DispName, //显示文本
							group_name: data_attr.GroupName, //属性组
							type: data_attr.Type, //字段类型
							readonly: data_attr.ReadOnly, //是否只读
							button_img: data_attr.button_img, //引用按钮的图标
							button_tooltip: data_attr.button_tooltip //引用按钮的tooltip
						}
					}
				}
				enviroment = Base64.encode(JSON.stringify(enviroment)); //将字符串转换为base64编码
				var input_param = Base64.encode(JSON.stringify(info.attr)); //将字符串转换为base64编码
				var global_attr = Base64.encode(JSON.stringify(this.global_attr)); //将字符串转换为base64编码
				if (info.dataJson)
					info.dataJson = Base64.encode(JSON.stringify(info.dataJson)); //将字符串转换为base64编码
				var obj_attr = {};
				info.attr.forEach(item => {
					obj_attr[item.attr] = item.value;
				});
				if (!info.eventid.includes('{')) info.eventid = '{' + info.eventid + '}';
				var dataInfo = {
					ed_type: info.edtype,
					start_transaction: true,
					class_id: info.clsid,
					class_name: '',
					event_id: info.eventid,
					event_name: '',
					data_obj_id: info.objid,
					obj_attr: obj_attr,
					prj_id: info.projectid,
					ref_cls_id: info.rclsid,
					rel_obj_id: info.robjid,
					user_login: info.userlogin,
					data_json: info.dataJson,
					compose_info: '',
					ext_info: enviroment,
					global_attr: global_attr,
					input_param: input_param,
				};
				console.log(dataInfo);
				// return;
				runCustomEvent(dataInfo).then(data => {
					if (data.ret != 0) {
						var tip = data.err_info ? typeof data.err_info == 'string' ? data
							.err_info :
							data
							.err_info.join('<br/>') : '';
						if (data.ret == 801) {
							if (this.param.Only_Script_Error) {
								let pos = tip.indexOf("：");
								if (pos > -1) tip = tip.substring(pos + 1);
							}
							uni.showModal({
								title: this.translateSys("tip"),
								content: tip,
								showCancel: false,
								confirmText: this.translateSys('close')
							});
						} else uni.showModal({
							title: this.translateSys("tip"),
							content: tip + ',' + this.translateSys('tip') + ':' + data
								.ret,
							showCancel: false,
							confirmText: this.translateSys('close')
						});
						return false
					} else {
						var tip = data.info ? typeof data.info == 'string' ? data.info : data
							.info
							.join(
								'<br/>') : '';
						if (tip) uni.showModal({
							title: this.translateSys("tip"),
							content: tip,
							showCancel: false,
							confirmText: this.translateSys('close')
						});

						var actionlist = data.action;
						if (actionlist) {
							console.log(actionlist);
							for (var i = 0; i < actionlist.length; i++) {
								var action = actionlist[i];
								if (action.action_type == 'set_dlg_attr') {
									var result = action.value;
									$this.setFormValues(result)
								} else if (action.action_type == 'set_dlg_attr_show') {
									var result = action.value;
									result.forEach(async (attr, key) => {
										$this.head_styledef.form.items
											.forEach(
												async (ele,
													index) => {
													//判断是否是栅格表单
													if (ele.name != 'Layout') {
														if (ele.fieldId == attr
															.attr) {
															ele.show = attr
																.show;
														}
													} else if (ele.name ==
														'Layout') {
														ele.setting.colList
															.forEach(
																col => {
																	if (col) {
																		if (col
																			.fieldId ==
																			attr
																			.attr
																		) {
																			col.show =
																				attr
																				.show;
																		}
																	}
																});
													}
												});
									});
									var head_styledef = JSON.parse(JSON.stringify($this.$data
										.head_styledef));
									$this.head_styledef = [];
									$this.head_styledef = head_styledef;
									// console.log($this.head_styledef);
								} else if (action.action_type == 'set_global_attr') {
									$this.global_attr = action.value || [];
								} else {
									uni.showModal({
										title: this.translateSys("tip"),
										content: this.translateSys(
												"quotation_mark_left") +
											action
											.action_type + this.translateSys(
												"quotation_mark_right") + this
											.translate(
												"tip_action_unprocessed"),
										showCancel: false,
										confirmText: this.translateSys('close')
									});
								}
							}
						}
						console.log($this.head_styledef);
						if (data.result) {
							$this.setFormValues(data.result)
						}
					}

				}).catch(ex => {
					// console.log(ex);
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys("error") + "3.1",
						content: exStr,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				});
			},
			dataObjRunCustomEvent_Return(eventid, data_attr, button_callback, item) {
				console.log("dataObjRunCustomEvent_Return", eventid, data_attr, button_callback)
				const $this = this
				var enviroment = {
					'function': '3000', // 功能点编号
					cls_id: $this.clsId, // 功能点主数据类标识
					'button': 'top', // top/bottom
					button_name: $this.translateSys('add2'),
					master: {
						cls_id: $this.clsId, // button=bottom时 master的cls_id
						//obj_id: ''  // button=bottom时 master的obj_id
					}
				};
				var obj_attr = $this.head_styledef.form.model;
				console.log(obj_attr);
				var req = Object.keys(obj_attr).map((a) => ({
					attr: a,
					value: obj_attr[a] || "",
				}));
				let global_attr = Base64.encode(JSON.stringify(this.global_attr))
				let data_json = Base64.encode(JSON.stringify(this.data_json))
				let ext_info = Base64.encode(JSON.stringify(this.ext_info))
				var obj_attr = {};
				req.forEach(item2 => {
					obj_attr[item2.attr] = item2.value;
				});
				let input_param = Base64.encode(
					JSON.stringify(
						Object.keys(obj_attr).map((a) => ({
							attr: a,
							value: obj_attr[a] || "",
						}))
					)
				);

				if (!eventid.includes('{')) eventid = '{' + eventid + '}';
				var dataInfo = {
					ed_type: "0",
					start_transaction: true,
					class_id: $this.clsId,
					class_name: '',
					event_id: eventid,
					event_name: '',
					data_obj_id: '',
					obj_attr: obj_attr,
					prj_id: '',
					ref_cls_id: '',
					rel_obj_id: '',
					user_login: '',
					data_json,
					compose_info: '',
					ext_info,
					global_attr,
					input_param: input_param,
				};
				console.log(dataInfo);
				// return;
				runCustomEvent(dataInfo).then(data => {
					if (data.ret != 0) {
						var tip = data.err_info ? typeof data.err_info == 'string' ? data
							.err_info :
							data
							.err_info.join('<br/>') : '';
						if (data.ret == 801) {
							if ($this.param.Only_Script_Error) {
								let pos = tip.indexOf("：");
								if (pos > -1) tip = tip.substring(pos + 1);
							}
							uni.showModal({
								title: $this.translateSys("tip"),
								content: tip,
								showCancel: false,
								confirmText: $this.translateSys('close')
							});
						} else uni.showModal({
							title: $this.translateSys("tip"),
							content: tip + ',' + $this.translateSys('tip') + ':' + data
								.ret,
							showCancel: false,
							confirmText: $this.translateSys('close')
						});
						return false
					} else {
						var tip = data.info ? typeof data.info == 'string' ? data.info : data
							.info
							.join(
								'<br/>') : '';
						if (tip) uni.showModal({
							title: $this.translateSys("tip"),
							content: tip,
							showCancel: false,
							confirmText: $this.translateSys('close')
						});

						if (data != "") {
							var actions = data.action;
							if (actions) {
								for (var i = 0; i < actions.length; i++) {
									var action = actions[i];
									console.log(action)
									var val = action.value;
									var enviroment = JSON.stringify(enviroment);

									if (action.action_type == 'open_panel') {
										var d = dialog({
											title: '<i class="ace-icon fa fa-info-circle"></i> ' +
												$this.translateSys("tip"),
											content: $this.translateSys(
													"quotation_mark_left") +
												action
												.action_type + $this.translateSys(
													"quotation_mark_right") + $this
												.translate(
													"tip_action_unprocessed")
										});
										d.show();
									} else if (action.action_type == 'open_select_userdlg') {
										var style = val.style;
										// style == 'user' ? '选择人员' : style == 'department' ? '选择部门' : style == 'role' ? '选择角色' : ''
										var param = {
											item: item,
											button_callback: button_callback,
											req: req,
											data_attr: data_attr
										}
										uni.navigateTo({
											url: '../selpsn/index?mulit=false&param=' +
												JSON
												.stringify(
													param),
											events: {
												AddPer(data, param) {
													// console.log(param);
													console.log(data);
													var callback_eventid = param
														.button_callback
														.trim();
													var info = {
														eventid: callback_eventid,
														edtype: "0",
														projectid: '',
														rclsid: '',
														robjid: '',
														userlogin: '',
														clsid: $this.clsId,
														objid: "",
														attr: param.req,
														inputparameter: data,
														dataJson: [],
													}
													$this.DataObjRunCustomEvent(info,
														param
														.data_attr);
												}
											}
										});
									} else if (action.action_type == 'open_data_query_dlg') {
										var d = dialog({
											title: '<i class="ace-icon fa fa-info-circle"></i> ' +
												$this.translateSys("tip"),
											content: $this.translateSys(
													"quotation_mark_left") +
												action
												.action_type + $this.translateSys(
													"quotation_mark_right") + $this
												.translate(
													"tip_action_unprocessed")
										});
										d.show();
									} else if (action.action_type == 'open_common_dlg') {

										if (val.common_dlg_id == 'check_list') {
											$this.setData({
												check_list: val.config
											})
											if (val.config.appear_style == 'sideslip') //判断是否是侧滑
												$this.setData({
													popupType: "right"
												})
											else
												$this.setData({
													popupType: "center"
												})
											// open 方法传入参数 等同在 uni-popup 组件上绑定 type属性
											$this.$refs.popup.open($this.popupType);
											var popupParam = {
												item: item,
												button_callback: button_callback,
												req: req,
												data_attr: data_attr
											}
											$this.setData({
												popupParam: popupParam
											})
										}
									} else if (action.action_type == 'open_project_query_dlg') {
										//console.log(action.value.select_range);
										//console.log(action.value.mulit_select);
										var priRel = '-1';
										if (action.value.select_range == '全部相关')
											priRel = '0';
										else if (action.value.select_range == '我负责的项目')
											priRel = '1';
										else if (action.value.select_range == '我创建的')
											priRel = '2';
										else if (action.value.select_range == '我参与的' || action
											.value
											.select_range == '我参加的')
											priRel = '3';
										else if (action.value.select_range == '我关注的')
											priRel = '4';
										else if (action.value.select_range == '我下属的项目')
											priRel = '5';
										var param_ = {
											item: item,
											button_callback: button_callback,
											req: req
										}
										uni.navigateTo({
											url: '../selPrj/index?relation=' + priRel +
												'&param=' +
												JSON.stringify(param_),
											events: {
												AddPer(data, param) {
													var attr = param.item.fieldId;
													$this.head_styledef.form.model[
															attr] =
														data[0].ID +
														';' + data[0].Name;

													// $this.classAttrList[param.index].Attr[param.iindex].Value=data[0].Name;
													// $this.classAttrList[param.index].Attr[param.iindex].ValID=data[0].ID+';'+data[0].Name;
													var callback_eventid = param
														.button_callback
														.trim();
													if (callback_eventid) {
														var info = {
															eventid: callback_eventid,
															edtype: "2",
															projectid: data[0].ID,
															rclsid: "",
															robjid: "",
															userlogin: "",
															clsid: $this.clsId,
															objid: "",
															attr: param.req,
															dataJson: [],
														}

														$this.DataObjRunCustomEvent(
															info);
													}
												}
											}
										});
									} else {
										uni.showModal({
											title: $this.translateSys("tip"),
											content: $this.translateSys(
													"quotation_mark_left") +
												action.action_type + $this.translateSys(
													"quotation_mark_right") + $this
												.translate(
													"tip_action_unprocessed"),
											showCancel: false,
											confirmText: $this.translateSys('close')
										});
									}
								}
							}
						} else {
							uni.showModal({
								title: $this.translateSys('tip') + "5.2",
								content: $this.translateSys("quotation_mark_left") +
									"before_click_button" + $this.translateSys(
										"quotation_mark_right") + $this.translateSys(
										"comma") + 'event_id' + eventid,
								showCancel: false,
								confirmText: $this.translateSys('close')
							});
						}
					}

				}).catch(ex => {
					// console.log(ex);
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: $this.translateSys('tip') + "5.1",
						content: exStr,
						showCancel: false,
						confirmText: $this.translateSys('close')
					});
				});
			},
			//确定
			async ok() {
				try {
					uni.showLoading({
						title: this.translateSys("loading"),
						mask: true
					});
					this.okLoading = true
					console.log(obj_attr)
					var obj_attr = this.head_styledef.form.model || {};
					console.log(obj_attr)
					let ret = await this.sava();

					this.okLoading = false
					uni.hideLoading();
					if (!ret) return;
					obj_attr.id = this.objId || "";
					console.log(this.$scope)
					const eventChannel = this.getOpenerEventChannel();
					// const eventChannel = this.getOpenerEventChannel();
					eventChannel.emit(this.type, obj_attr);

					uni.navigateBack()
				} catch (ex) {
					this.okLoading = true
					return false;
				}
			},
			async sava() {
				try {
					if (this.objId) {

						let ret = await this.beforeOK();
						if (!ret) return false;
						if (this.afterOKEvent?.id) { // 点击确定按钮后
							ret = await this.afterOK();
							if (!ret) return false;

						} else {
							ret = await this.update();
							if (!ret) return false;
						}

					} else {
						if (this.editMode) {
							return true
						} else {
							let ret = await this.beforeOK();
							if (!ret) return false;
							if (this.afterOKEvent?.id) { // 点击确定按钮后
								ret = await this.afterOK();
								if (!ret) return false;
							} else {
								ret = await this.add();
								if (!ret) return false;
							}
						}
					}
					return true;
				} catch (ex) {
					console.log("sava", ex)
					this.showError(ex)
					return false;
				}

			},
			async beforeOK() {

				try {
					if (!this.beforeOKEvent.id) return true;


					const $this = this
					var obj_attr = this.head_styledef.form.model;
					// console.log(obj_attr);
					var input_param = {
						id: "",
						attrs: Object.keys(obj_attr).map((a) => ({
							attr: a,
							value: obj_attr[a],
						})),
					};
					let global_attr = Base64.encode(JSON.stringify(this.global_attr))
					let data_json = Base64.encode(JSON.stringify(this.data_json))
					let ext_info = Base64.encode(JSON.stringify(this.ext_info))
					var dataInfo = {
						ed_type: "0",
						start_transaction: true,
						class_id: this.clsId,
						class_name: '',
						event_id: this.beforeOKEvent?.id,
						event_name: '',
						data_obj_id: this.objId,
						obj_attr: obj_attr,
						prj_id: '',
						ref_cls_id: '',
						rel_obj_id: '',
						user_login: '',
						global_attr,
						data_json,
						ext_info,
						compose_info: '',
						input_param: Base64.encode(JSON.stringify(input_param)),
					};
					await runCustomEvent(dataInfo)
					return true
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys('tip') + "7.1",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}

			},

			async add() {
				try {

					var obj_attr = this.head_styledef.form.model || {};

					var dataInfo = {
						class_id: this.clsId,
						obj_attr: obj_attr
					};
					await dataObjCreate(dataInfo)
					return true
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys("tip") + "6.1",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}

			},
			async update() {
				try {
					var obj_attr = this.head_styledef.form.model || {};

					var dataInfo = {
						class_id: this.clsId,
						obj_id: this.objId,
						obj_attr: obj_attr
					};
					await dataObjUpdate(dataInfo)
					return true

				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys("tip") + "6.2",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}

			},
			async afterOK() {

				try {
					var obj_attr = this.head_styledef.form.model || {}
					// console.log(obj_attr);
					var input_param = {
						id: "",
						attrs: Object.keys(obj_attr).map((a) => ({
							attr: a,
							value: obj_attr[a],
						})),
					};
					let global_attr = Base64.encode(JSON.stringify(this.global_attr))
					let data_json = Base64.encode(JSON.stringify(this.data_json))
					let ext_info = Base64.encode(JSON.stringify(this.ext_info))
					var dataInfo = {
						ed_type: "0",
						start_transaction: true,
						class_id: this.clsId,
						class_name: '',
						event_id: this.afterOKEvent?.id,
						event_name: '',
						data_obj_id: this.objId,
						obj_attr: obj_attr,
						prj_id: '',
						ref_cls_id: '',
						rel_obj_id: '',
						user_login: '',
						global_attr,
						data_json,
						ext_info,
						compose_info: '',
						input_param: Base64.encode(JSON.stringify(input_param)),
					};
					await runCustomEvent(dataInfo)
					return true
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys('tip') + "7.2",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}

			},

			async cancel(e) { //取消
				try {
					if (!this.objId) {
						if (this.editMode) {
							uni.navigateBack({
								delta: 1 //返回层数，2则上上页
							});
							return
						}
					}

					let ret = await this.beforeCancel();
					if (!ret) return false;

					uni.navigateBack({
						delta: 1 //返回层数，2则上上页
					});
					await this.afterCancel();
				} catch (ex) {}
			},
			async beforeCancel() {
				try {
					if (!this.beforeCancelEvent.id) return true;
					var obj_attr = this.head_styledef.form.model;

					let inputParam = {
						id: "",
						attrs: Object.keys(obj_attr).map((a) => ({
							attr: a,
							value: obj_attr[a],
						})),
					};
					let input_param = Base64.encode(JSON.stringify(
						inputParam));
					let global_attr = Base64.encode(JSON.stringify(this
						.global_attr))
					let data_json = Base64.encode(JSON.stringify(this
						.data_json))
					let ext_info = Base64.encode(JSON.stringify(this.ext_info))

					await runCustomEvent({
						ed_type: 0,
						start_transaction: true,
						class_id: this.clsId,
						event_id: this.beforeCancelEvent.id,
						data_obj_id: this.objId,
						obj_attr,
						input_param,
						global_attr,
						data_json,
						ext_info,
					})
					return true
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : exStr
					uni.showModal({
						title: this.translateSys("tip") + "8.1",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}
			},
			async afterCancel() {
				try {
					if (!this.afterCancelEvent.id) return true;
					var obj_attr = this.head_styledef.form.model;
					let inputParam = {
						id: "",
						attrs: Object.keys(obj_attr).map((a) => ({
							attr: a,
							value: obj_attr[a],
						})),
					};
					let input_param = Base64.encode(JSON.stringify(
						inputParam));
					let global_attr = Base64.encode(JSON.stringify(this
						.global_attr))
					let data_json = Base64.encode(JSON.stringify(this
						.data_json))
					let ext_info = Base64.encode(JSON.stringify(this
						.ext_info))

					await runCustomEvent({
						ed_type: 0,
						start_transaction: true,
						class_id: this.clsId,
						event_id: this.afterCancelEvent.id,
						data_obj_id: this.objId,
						obj_attr,
						input_param,
						global_attr,
						data_json,
						ext_info,
					})
					return true
				} catch (ex) {
					let exStr = JSON.stringify(ex)
					if (exStr == "{}")
						exStr = ex
					let tip = typeof ex.errMsg == "string" ? ex.errMsg :
						exStr
					uni.showModal({
						title: this.translateSys("tip") + "8.2",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
					return false
				}
			},
			showError(ex) {
				uni.showModal({
					title: this.translateSys('error'),
					content: typeof ex == "string" ? ex : typeof ex.errMsg == "string" ? ex.errMsg : "",
					showCancel: false,
					confirmText: this.translateSys('cancel')
				})
			},
			translate(t) {
				if (typeof this.$t == "function") return this.$t(
					`page.${t}`)
				else return t;
			},
			translateSys(t) {
				if (typeof this.$t == "function") return this.$t(
					`sys.${t}`)
				else return t;
			},
		},
	};
</script>

<style lang="scss">
	.uni-page-modal-form {

		display: flex;
		height: calc(100vh - 30rpx);
		width: 720rpx;
		flex-direction: column !important;
		padding: 15rpx;

		.view-header {
			display: flex;
			width: 100%;
			flex-direction: column;
		}

		.v-head-style {
			width: 98%;

			.uni-forms-item {
				margin-bottom: 11rpx;
			}

			.input-wrapper {
				border: 1px solid #d5d5d5;
				width: 100%;
				display: flex;
				flex-direction: row;

				.uni-input {
					flex: 1;
					padding: 12rpx 8rpx;
					color: #2d8cf0;
					// height: 40rpx;
					// line-height: 40rpx;
				}

				.uni-icon {

					padding: 10rpx 5rpx;
					font-size: 32rpx;
					color: rgb(192, 196, 204);
				}
			}

			.input-wrapper:hover {
				border: 1px solid rgb(41, 121, 255);
			}
		}

		.view-content {
			display: flex;
			flex: 1;
			width: calc(100% - 30rpx);
			padding: 10rpx 15rpx;
			flex-direction: column;
			overflow-y: auto;

		}

		.view-bottom {
			// display: flex;
			// flex-direction: row;
			display: block;
			width: calc(100% - 30rpx);
			padding: 10rpx 15rpx 20rpx 15rpx;

			.btn_add {
				width: 45%;
				margin: 0 10rpx;
				// padding: 5rpx 10rpx;
				background: #4D6AF4;
				font-size: 38rpx;
				border: none;
				color: #fff;
				float: left;
				display: inline-block;
			}

			.btn_disabled {
				background-color: #ddd;
				color: #888;
			}

			.btn_cancel {
				width: 45%;
				margin: 0 10rpx;
				// background: #fff;
				// border: none;
				// color: #000;
				background: #fff;
				color: #000;
				font-size: 38rpx;
				float: right;
				display: inline-block;
			}

		}




		[nvue] uni-view {
			position: relative;
			border: 0 solid #000;
			box-sizing: border-box;
		}

		.uni-icon {
			/* border: 1px solid red; */
			width: 30rpx;
			font-family: uniicons;
			font-size: 40rpx;
			font-weight: 400;
			font-style: normal;
			/* width: 48rpx; */
			height: 48rpx;
			line-height: 48rpx;
			color: #2d8cf0;
			cursor: pointer;
			display: inline-block;
			vertical-align: 18rpx;
		}



		.input-disabled {
			background-color: #f3f3f3 !important;
		}


		::v-deep .uni-row {
			margin-bottom: 0px;
		}

		.popup-header {
			font-size: 42rpx;
			font-weight: bold;
			margin: 20rpx 20rpx 0px 20rpx;
		}

		.view_popup_CheckList {
			margin-bottom: 20rpx;
		}

		.popup-footer {
			float: right;
			position: absolute;
			bottom: 10rpx;
			right: 20rpx;
		}

		button.btn_popup_add {
			width: 180rpx;
			margin-top: 50rpx;
			margin-right: 20rpx;
			padding: 15rpx;
			line-height: 1.5;
			background: #27A6E1;
			border: none;
			color: #fff;
			font-size: 38rpx;
			font-weight: bold;
			/* float: left; */
			display: inline-block;
		}

		button.btn_popup_cancel {
			width: 180rpx;
			margin-top: 50rpx;
			padding: 15rpx;
			line-height: 1.5;
			// background: #27A6E1;
			// border: none;
			// color: #fff;
			background: #fff;
			color: #000;
			font-size: 38rpx;
			font-weight: bold;
			/* float: right; */
			display: inline-block;
		}


	}
</style>